==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_nl.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Wat een geweldige beschaving. Eeuwenlang onderwater en toch doen hun liften het nog.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Vooral als we ze duwen.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Maar alleen naar beneden.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Zie je deze schelp?")


dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")
dialogStr("Er is een eeuwen oud gezegd van liftenbouwers: Een stevig bouwerk, bouw je met schelp.")


dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")
dialogStr("Die schelp komt me bekend voor.")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Ze zouden zich moeten schamen! Dit is sluikreclame.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Die schedel ziet er bekend uit.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Alle menselijke schedels zien er het zelfde uit... In tegenstelling to visskelleten.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Dit is een moeilijke route.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Ik voel me net een muis in een tredmolentje.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Een tredmolen voor vissen? Maar we hebben alleen vinnen.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")
dialogStr("Joehoe, Joehoeoeoeoe... Ik ben hier...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")
dialogStr("Joehoe! Als je wil vertel ik je hoe je alle velden kunt oplossen...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Joehoe! Ik weet waarom de stad is gezonken!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")
dialogStr("Heeeee! Waarom luistert niemand naar mij?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Joehoe! Waarom negeren jullie mij?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hee, haaaaallooo, visjes! Luister nou!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_nl.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Wat een geweldige beschaving. Eeuwenlang onderwater en toch doen hun liften het nog.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Vooral als we ze duwen.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Maar alleen naar beneden.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Zie je deze schelp?")


dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")
dialogStr("Er is een eeuwen oud liftenbouwers gezegde: Een stevig bouwerk bouw je met schelp.")


dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")
dialogStr("Die schelp komt me bekend voor.")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Ze zouden zich moeten schamen! Dit is sluikreclame.")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Die schedel ziet er bekend uit.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Alle menselijke schedels zien er het zelfde uit... In tegenstelling to visskelleten.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Dit is een moeilijk pad.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Ik voel me net een muis in een tredmolentje.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Een tredmolen voor vissen? Maar we hebben alleen vinnen.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")
dialogStr("Joehoe, Joehoeoeoeoe... Ik ben hier...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")
dialogStr("Joehoe! Als je wilt vertel ik je hoe je alle velden kunt oplossen...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Joehoe! Ik weet waarom de stad is gezonken!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")
dialogStr("Heeeee! Waarom luistert niemand naar mij?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Joehoe! Waarom negeren jullie mij?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hee, haaaaallooo, visjes! Luister nou!")
